@@ -1,4 +1,6 @@
-// Copyright (C) 2003 Free Software Foundation, Inc.
+// { dg-require-namedlocale "" }
+
+// Copyright (C) 2003, 2005 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -13,7 +15,7 @@
 
 // You should have received a copy of the GNU General Public License along
 // with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 // USA.
 
 // 27.5.2.4.1 Locales
@@ -22,28 +24,40 @@
 #include <locale>
 #include <testsuite_hooks.h>
 
-class Buf1 : public std::streambuf
+class Buf2 : public std::streambuf
 {
+public:
+  std::locale before;
+  std::locale after;
+
 protected:
-  void imbue(const std::locale&)
-  { }
+  void imbue(const std::locale& loc)
+  {
+    before = getloc();
+
+    std::streambuf::imbue(loc);
+
+    after = getloc();
+  }
 };
 
 // libstdc++/13007
-void test01()
+void test02()
 {
   bool test __attribute__((unused)) = true;
-  
-  Buf1 buf;
-  std::locale loc(__gnu_test::try_named_locale("is_IS.UTF-8"));
+
+  Buf2 buf;
+  std::locale loc(std::locale("en_US"));
 
   buf.pubimbue(loc);
 
   VERIFY( buf.getloc() == loc );
+  VERIFY( buf.before == std::locale::classic() );
+  VERIFY( buf.after == std::locale::classic() );
 }
 
 int main()
 {
-  test01();
+  test02();
   return 0;
 }
