@@ -2,7 +2,8 @@
 // 2000-05-21 Benjamin Kosnik  <bkoz@redhat.com>
 // 2001-01-17 Loren J. Rittle  <ljrittle@acm.org>
 
-// Copyright (C) 1999, 2000, 2001, 2003 Free Software Foundation
+// Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+// Free Software Foundation
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -35,19 +36,19 @@ void
 test01()
 {
   std::ios_base::sync_with_stdio();
-  std::freopen("ios_base_members_static-1.txt", "w", stdout);
+  std::freopen("ios_base_members_static-1.txt", "w", stderr);
  
   for (int i = 0; i < 2; i++)
     {
-      std::printf("1");
-      std::cout << "2";
-      std::putc('3', stdout); 
-      std::cout << '4';
-      std::fputs("5", stdout);
-      std::cout << 6;
-      std::putchar('7');
-      std::cout << 8 << '9';
-      std::printf("0\n");
+      std::fprintf(stderr, "1");
+      std::cerr << "2";
+      std::putc('3', stderr); 
+      std::cerr << '4';
+      std::fputs("5", stderr);
+      std::cerr << 6;
+      std::putc('7', stderr);
+      std::cerr << 8 << '9';
+      std::fprintf(stderr, "0\n");
     }
 }
 
